Installation
===========================

Hist is available on `PyPI <https://pypi.org/project/hist/>`__. You can install this library from PyPI with pip:

.. code-block:: bash

   python3 -m pip install "hist[plot]"

If you do not need the plotting features, you can skip the ``[plot]`` extra.

You can also install it with Conda from conda-forge.

.. code-block:: bash

   conda install -c conda-forge hist


Supported platforms are identical to
`boost-histogram <https://boost-histogram.readthedocs.io/en/latest/user-guide/installation.html>`_.
